@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2009, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -15,7 +15,7 @@ package ch.qos.logback.access.pattern;
 
 import java.util.Arrays;
 
-import ch.qos.logback.access.spi.AccessEvent;
+import ch.qos.logback.access.spi.IAccessEvent;
 import ch.qos.logback.core.util.OptionHelper;
 
 public class RequestParameterConverter extends AccessConverter {
@@ -31,7 +31,7 @@ public class RequestParameterConverter extends AccessConverter {
     }
   }
 
-  public String convert(AccessEvent accessEvent) {
+  public String convert(IAccessEvent accessEvent) {
     if (!isStarted()) {
       return "INACTIVE_REQUEST_PARAM_CONV";
     }
