@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2009, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -37,7 +37,7 @@ public final class Level implements java.io.Serializable {
   public static final Integer WARN_INTEGER = new Integer(WARN_INT);
   public static final Integer INFO_INTEGER = new Integer(INFO_INT);
   public static final Integer DEBUG_INTEGER = new Integer(DEBUG_INT);
-  public static final Integer TRACE_INTEGER = new Integer(DEBUG_INT);
+  public static final Integer TRACE_INTEGER = new Integer(TRACE_INT);
   public static final Integer ALL_INTEGER = new Integer(ALL_INT);
 
   /**
