@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2009, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -29,7 +29,7 @@ import ch.qos.logback.core.status.ErrorStatus;
 
 /**
  * Add a stack trace in case the event contains a Throwable.
- * 
+ *
  * @author Ceki G&uuml;lc&uuml;
  */
 public class ThrowableProxyConverter extends ThrowableHandlingConverter {
@@ -37,7 +37,6 @@ public class ThrowableProxyConverter extends ThrowableHandlingConverter {
   int lengthOption;
   List<EventEvaluator<ILoggingEvent>> evaluatorList = null;
 
-  final int MAX_ERROR_COUNT = 4;
   int errorCount = 0;
 
   @SuppressWarnings("unchecked")
@@ -73,7 +72,7 @@ public class ThrowableProxyConverter extends ThrowableHandlingConverter {
         Context context = getContext();
         Map evaluatorMap = (Map) context.getObject(CoreConstants.EVALUATOR_MAP);
         EventEvaluator<ILoggingEvent> ee = (EventEvaluator<ILoggingEvent>) evaluatorMap
-            .get(evaluatorStr);
+                .get(evaluatorStr);
         addEvaluator(ee);
       }
     }
@@ -97,7 +96,6 @@ public class ThrowableProxyConverter extends ThrowableHandlingConverter {
   }
 
   public String convert(ILoggingEvent event) {
-    StringBuilder buf = new StringBuilder(32);
 
     IThrowableProxy tp = event.getThrowableProxy();
     if (tp == null) {
@@ -116,16 +114,16 @@ public class ThrowableProxyConverter extends ThrowableHandlingConverter {
           }
         } catch (EvaluationException eex) {
           errorCount++;
-          if (errorCount < MAX_ERROR_COUNT) {
+          if (errorCount < CoreConstants.MAX_ERROR_COUNT) {
             addError("Exception thrown for evaluator named [" + ee.getName()
-                + "]", eex);
-          } else if (errorCount == MAX_ERROR_COUNT) {
+                    + "]", eex);
+          } else if (errorCount == CoreConstants.MAX_ERROR_COUNT) {
             ErrorStatus errorStatus = new ErrorStatus(
-                "Exception thrown for evaluator named [" + ee.getName() + "].",
-                this, eex);
+                    "Exception thrown for evaluator named [" + ee.getName() + "].",
+                    this, eex);
             errorStatus.add(new ErrorStatus(
-                "This was the last warning about this evaluator's errors."
-                    + "We don't want the StatusManager to get flooded.", this));
+                    "This was the last warning about this evaluator's errors."
+                            + "We don't want the StatusManager to get flooded.", this));
             addStatus(errorStatus);
           }
         }
@@ -136,15 +134,21 @@ public class ThrowableProxyConverter extends ThrowableHandlingConverter {
       }
     }
 
-    while (tp != null) {
-      printThrowableProxy(buf, tp);
-      tp = tp.getCause();
+    return throwableProxyToString(tp);
+  }
+
+  protected String throwableProxyToString(IThrowableProxy tp) {
+    StringBuilder buf = new StringBuilder(32);
+    IThrowableProxy currentThrowable = tp;
+    while (currentThrowable != null) {
+      subjoinThrowableProxy(buf, currentThrowable);
+      currentThrowable = currentThrowable.getCause();
     }
     return buf.toString();
   }
 
-  void printThrowableProxy(StringBuilder buf, IThrowableProxy tp) {
-    ThrowableProxyUtil.printFirstLine(buf, tp);
+  void subjoinThrowableProxy(StringBuilder buf, IThrowableProxy tp) {
+    ThrowableProxyUtil.subjoinFirstLine(buf, tp);
     buf.append(CoreConstants.LINE_SEPARATOR);
     StackTraceElementProxy[] stepArray = tp.getStackTraceElementProxyArray();
     int commonFrames = tp.getCommonFrames();
@@ -167,8 +171,8 @@ public class ThrowableProxyConverter extends ThrowableHandlingConverter {
     }
 
     if (commonFrames > 0 && unrestrictedPrinting) {
-      buf.append("\t... " + tp.getCommonFrames()).append(
-          " common frames omitted").append(CoreConstants.LINE_SEPARATOR);
+      buf.append("\t... ").append(tp.getCommonFrames()).append(
+              " common frames omitted").append(CoreConstants.LINE_SEPARATOR);
     }
   }
 }
