@@ -18,6 +18,7 @@ import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
 
 import java.io.IOException;
+import java.util.concurrent.TimeUnit;
 
 import javax.mail.MessagingException;
 import javax.mail.internet.MimeMessage;
@@ -118,6 +119,10 @@ public class SMTPAppender_GreenTest {
     return (MimeMultipart) mm.getContent();
   }
 
+  void waitUntilEmailIsSent() throws InterruptedException {
+    lc.getExecutorService().shutdown();
+    lc.getExecutorService().awaitTermination(1000, TimeUnit.MILLISECONDS);
+  }
   @Test
   public void smoke() throws Exception {
     buildSMTPAppender();
@@ -127,6 +132,11 @@ public class SMTPAppender_GreenTest {
     logger.debug("hello");
     logger.error("en error", new Exception("an exception"));
 
+     waitUntilEmailIsSent();
+//    synchronized (smtpAppender) {
+//      smtpAppender.wait();
+//    }
+
     StatusPrinter.print(lc);
     MimeMultipart mp = verify(TEST_SUBJECT);
     String body = GreenMailUtil.getBody(mp.getBodyPart(0));
@@ -145,6 +155,7 @@ public class SMTPAppender_GreenTest {
     MDC.clear();
     logger.error("en error", new Exception("an exception"));
 
+    waitUntilEmailIsSent();
     MimeMultipart mp = verify(TEST_SUBJECT);
     String body = GreenMailUtil.getBody(mp.getBodyPart(0));
     assertTrue(body.startsWith(HEADER.trim()));
@@ -160,6 +171,8 @@ public class SMTPAppender_GreenTest {
     logger.addAppender(smtpAppender);
     logger.debug("hello");
     logger.error("en error", new Exception("an exception"));
+
+    waitUntilEmailIsSent();
     MimeMultipart mp = verify(TEST_SUBJECT);
 
     // verify strict adherence to xhtml1-strict.dtd
@@ -188,6 +201,7 @@ public class SMTPAppender_GreenTest {
     }
     logger.error("en error", new Exception("an exception"));
 
+     waitUntilEmailIsSent();
     MimeMultipart mp = verify(TEST_SUBJECT);
 
     // verify strict adherence to xhtml1-strict.dtd
@@ -214,6 +228,7 @@ public class SMTPAppender_GreenTest {
     String msg2 = "world";
     logger.debug(msg2);
     logger.debug("invisible");
+    waitUntilEmailIsSent();
     MimeMultipart mp = verify(this.getClass().getName() + " - " + msg2);
     String body = GreenMailUtil.getBody(mp.getBodyPart(0));
     assertEquals("helloworld", body);
@@ -228,6 +243,7 @@ public class SMTPAppender_GreenTest {
     logger.debug("invisible2");
     String msg = "hello";
     logger.error(msg);
+    waitUntilEmailIsSent();
     MimeMultipart mp = verify(this.getClass().getName() + " - " + msg);
     String body = GreenMailUtil.getBody(mp.getBodyPart(0));
     assertEquals(msg, body);
@@ -243,8 +259,7 @@ public class SMTPAppender_GreenTest {
     logger.debug("hello");
     logger.error("en error", new Exception("an exception"));
 
-    StatusPrinter.print(lc);
-
+    waitUntilEmailIsSent();
     MimeMessage[] mma = greenMail.getReceivedMessages();
     assertNotNull(mma);
     assertEquals(3, mma.length);
