@@ -1,11 +1,15 @@
 /**
- * Logback: the generic, reliable, fast and flexible logging framework.
- * 
- * Copyright (C) 2000-2008, QOS.ch
- * 
- * This library is free software, you can redistribute it and/or modify it under
- * the terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation.
+ * Logback: the reliable, generic, fast and flexible logging framework.
+ * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ *
+ * This program and the accompanying materials are dual-licensed under
+ * either the terms of the Eclipse Public License v1.0 as published by
+ * the Eclipse Foundation
+ *
+ *   or (per the licensee's choosing)
+ *
+ * under the terms of the GNU Lesser General Public License version 2.1
+ * as published by the Free Software Foundation.
  */
 package ch.qos.logback.classic.net.testObjectBuilders;
 
@@ -19,7 +23,7 @@ public class LoggingEventWithParametersBuilder implements Builder {
   final String MSG = "aaaaabbbbbcccc {} cdddddaaaaabbbbbcccccdddddaaaa {}";
 
   private Logger logger = new LoggerContext()
-      .getLogger(LoggerContext.ROOT_NAME);
+      .getLogger(Logger.ROOT_LOGGER_NAME);
 
   public Object build(int i) {
 
@@ -37,7 +41,8 @@ public class LoggingEventWithParametersBuilder implements Builder {
     // exercise)
     le.getFormattedMessage();
     le.setLevel(Level.DEBUG);
-    le.setLoggerRemoteView(logger.getLoggerRemoteView());
+    le.setLoggerName(logger.getName());
+    le.setLoggerContextRemoteView(logger.getLoggerRemoteView().getLoggerContextView());
     le.setThreadName("threadName");
 
     return le;
