@@ -13,21 +13,23 @@
  */
 package ch.qos.logback.classic.turbo;
 
-import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.io.*;
 import java.net.MalformedURLException;
-import java.util.Random;
+import java.util.concurrent.ThreadPoolExecutor;
 
 import ch.qos.logback.classic.gaffer.GafferConfigurator;
+import ch.qos.logback.core.contention.AbstractMultiThreadedHarness;
+import ch.qos.logback.core.contention.MultiThreadedHarness;
+import ch.qos.logback.core.contention.WaitOnExecutionMultiThreadedHarness;
 import ch.qos.logback.core.joran.util.ConfigurationWatchListUtil;
+import ch.qos.logback.core.testUtil.FileTestUtil;
 import ch.qos.logback.core.testUtil.RandomUtil;
 import ch.qos.logback.core.util.CoreTestConstants;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.*;
 import org.slf4j.helpers.BogoPerf;
 
 import ch.qos.logback.classic.ClassicTestConstants;
@@ -37,7 +39,6 @@ import ch.qos.logback.classic.LoggerContext;
 import ch.qos.logback.classic.issue.lbclassic135.LoggingRunnable;
 import ch.qos.logback.classic.joran.JoranConfigurator;
 import ch.qos.logback.core.CoreConstants;
-import ch.qos.logback.core.contention.MultiThreadedHarness;
 import ch.qos.logback.core.contention.RunnableWithCounterAndDone;
 import ch.qos.logback.core.joran.spi.JoranException;
 import ch.qos.logback.core.status.InfoStatus;
@@ -52,6 +53,9 @@ public class ReconfigureOnChangeTest {
   static final boolean MUST_BE_ERROR_FREE = true;
   static final boolean ERRORS_EXPECTED = false;
 
+  static final boolean REGULAR_RECONFIGURATION = false;
+  static final boolean FORCED_RECONFIGURATION_SKIP = true;
+
 
   int diff = RandomUtil.getPositiveInt();
 
@@ -87,32 +91,32 @@ public class ReconfigureOnChangeTest {
   // it actually takes time for Windows to propagate file modification changes
   // values below 100 milliseconds can be problematic the same propagation
   // latency occurs in Linux but is even larger (>600 ms)
-  final static int DEFAULT_SLEEP_BETWEEN_UPDATES = 210;
+  final static int DEFAULT_SLEEP_BETWEEN_UPDATES = 60;
 
-  int sleepBetweenUpdates = DEFAULT_SLEEP_BETWEEN_UPDATES;
+  int sleepBetweenUpdates = 100;//DEFAULT_SLEEP_BETWEEN_UPDATES;
 
-  static int totalTestDuration;
+//  static int totalTestDuration;
 
   LoggerContext loggerContext = new LoggerContext();
   Logger logger = loggerContext.getLogger(this.getClass());
-  MultiThreadedHarness harness;
+  AbstractMultiThreadedHarness harness;
+
+  ThreadPoolExecutor executor = (ThreadPoolExecutor) loggerContext.getExecutorService();
+
+  int expectedResets = 2;
+
+  @BeforeClass
+  static public void classSetup() {
+    FileTestUtil.makeTestOutputDir();
+  }
 
   @Before
   public void setUp() {
-    System.out.println("======== TEST START, time" + System.currentTimeMillis());
-    // take into account propagation latency occurs on Linux or Mac
-    if (Env.isLinux() || Env.isMac()) {
-      sleepBetweenUpdates = 950;
-      totalTestDuration = sleepBetweenUpdates * 5;
-    } else {
-      totalTestDuration = sleepBetweenUpdates * 10;
-    }
-    harness = new MultiThreadedHarness(totalTestDuration);
+    harness = new WaitOnExecutionMultiThreadedHarness(executor, expectedResets);
   }
 
   @After
   public void tearDown() {
-    System.out.println("======= TEST STOP");
   }
 
   void configure(File file) throws JoranException {
@@ -143,7 +147,7 @@ public class ReconfigureOnChangeTest {
 
 
   void doScanTest(File fileToTouch) throws JoranException, IOException, InterruptedException {
-    doScanTest(fileToTouch, UpdateType.TOUCH, false, MUST_BE_ERROR_FREE);
+    doScanTest(fileToTouch, UpdateType.TOUCH, REGULAR_RECONFIGURATION, MUST_BE_ERROR_FREE);
   }
 
   void doScanTest(File fileToTouch, UpdateType updateType, boolean forcedReconfigurationSkip, boolean mustBeErrorFree) throws JoranException, IOException, InterruptedException {
@@ -153,46 +157,22 @@ public class ReconfigureOnChangeTest {
     loggerContext.getStatusManager().add(
             new InfoStatus("end of execution ", this));
 
-    long expectedReconfigurations = runnableArray[0].getCounter();
+    int expected = expectedResets;
     if (forcedReconfigurationSkip)
-      expectedReconfigurations = 0;
+      expected = 0;
 
-    verify(expectedReconfigurations, mustBeErrorFree);
-  }
-
-  // chose a test at random. These tests are rather long...
-  // check for deadlocks
-  @Test(timeout = 20000)
-  public void randomTest() throws JoranException, IOException, InterruptedException {
-    Random rand = new Random(System.currentTimeMillis());
-    switch (rand.nextInt(5)) {
-      case 0:
-        scan1();
-        break;
-      case 1:
-        scanWithFileInclusion();
-        break;
-      case 2:
-        scanWithResourceInclusion();
-        break;
-      case 3:
-        scan_lbclassic154();
-        break;
-      case 4:
-        gscan1();
-        break;
-    }
+    verify(expected, mustBeErrorFree);
   }
 
   // Tests whether ConfigurationAction is installing ReconfigureOnChangeFilter
-  @Test
+  @Test(timeout = 4000L)
   public void scan1() throws JoranException, IOException, InterruptedException {
     File file = new File(SCAN1_FILE_AS_STR);
     configure(file);
     doScanTest(file);
   }
 
-  @Test
+  @Test(timeout = 4000L)
   public void scanWithFileInclusion() throws JoranException, IOException, InterruptedException {
     File topLevelFile = new File(INCLUSION_SCAN_TOPLEVEL0_AS_STR);
     File innerFile = new File(INCLUSION_SCAN_INNER0_AS_STR);
@@ -200,7 +180,7 @@ public class ReconfigureOnChangeTest {
     doScanTest(innerFile);
   }
 
-  @Test
+  @Test(timeout = 4000L)
   public void scanWithResourceInclusion() throws JoranException, IOException, InterruptedException {
     File topLevelFile = new File(INCLUSION_SCAN_TOP_BY_RESOURCE_AS_STR);
     File innerFile = new File(INCLUSION_SCAN_INNER1_AS_STR);
@@ -209,24 +189,25 @@ public class ReconfigureOnChangeTest {
   }
 
   // See also http://jira.qos.ch/browse/LBCLASSIC-247
-  @Test
+  @Test(timeout = 4000L)
   public void includeScanViaInputStreamSuppliedConfigFile() throws IOException, JoranException, InterruptedException {
+    harness = new MultiThreadedHarness(1000);
     String configurationStr = "<configuration scan=\"true\" scanPeriod=\"50 millisecond\"><include resource=\"asResource/inner1.xml\"/></configuration>";
     configure(new ByteArrayInputStream(configurationStr.getBytes("UTF-8")));
     File innerFile = new File(INCLUSION_SCAN_INNER1_AS_STR);
-    doScanTest(innerFile, UpdateType.TOUCH, true, MUST_BE_ERROR_FREE);
+    doScanTest(innerFile, UpdateType.TOUCH, FORCED_RECONFIGURATION_SKIP, MUST_BE_ERROR_FREE);
   }
 
-  @Test
+  @Test(timeout = 4000L)
   public void fallbackToSafe() throws IOException, JoranException, InterruptedException {
     String path = CoreTestConstants.OUTPUT_DIR_PREFIX + "reconfigureOnChangeConfig_fallbackToSafe-" + diff + ".xml";
     File file = new File(path);
     writeToFile(file, "<configuration scan=\"true\" scanPeriod=\"50 millisecond\"><root level=\"ERROR\"/></configuration> ");
     configure(file);
-    doScanTest(file, UpdateType.MALFORMED, false, ERRORS_EXPECTED);
+    doScanTest(file, UpdateType.MALFORMED, REGULAR_RECONFIGURATION, ERRORS_EXPECTED);
   }
 
-  @Test
+  @Test(timeout = 4000L)
   public void fallbackToSafeWithIncludedFile() throws IOException, JoranException, InterruptedException {
     String topLevelFileAsStr = CoreTestConstants.OUTPUT_DIR_PREFIX + "reconfigureOnChangeConfig_top-" + diff + ".xml";
     String innerFileAsStr = CoreTestConstants.OUTPUT_DIR_PREFIX + "reconfigureOnChangeConfig_inner-" + diff + ".xml";
@@ -236,11 +217,11 @@ public class ReconfigureOnChangeTest {
     File innerFile = new File(innerFileAsStr);
     writeToFile(innerFile, "<included><root level=\"ERROR\"/></included> ");
     configure(topLevelFile);
-    doScanTest(innerFile, UpdateType.MALFORMED_INNER, false, ERRORS_EXPECTED);
+    doScanTest(innerFile, UpdateType.MALFORMED_INNER, REGULAR_RECONFIGURATION, ERRORS_EXPECTED);
   }
 
 
-  @Test
+  @Test(timeout = 4000L)
   public void gscan1() throws JoranException, IOException, InterruptedException {
     File file = new File(G_SCAN1_FILE_AS_STR);
     gConfigure(file);
@@ -250,13 +231,11 @@ public class ReconfigureOnChangeTest {
     loggerContext.getStatusManager().add(
             new InfoStatus("end of execution ", this));
 
-    long expectedRreconfigurations = runnableArray[0].getCounter();
-    verify(expectedRreconfigurations, MUST_BE_ERROR_FREE);
+    verify(expectedResets, MUST_BE_ERROR_FREE);
   }
 
   // check for deadlocks
-  //Attr_Test(timeout = 20000)
-  @Test
+  @Test(timeout = 4000L)
   public void scan_lbclassic154() throws JoranException, IOException,
           InterruptedException {
     File file = new File(SCAN_LBCLASSIC_154_FILE_AS_STR);
@@ -267,12 +246,11 @@ public class ReconfigureOnChangeTest {
     loggerContext.getStatusManager().add(
             new InfoStatus("end of execution ", this));
 
-    long expectedReconfigurations = runnableArray[0].getCounter();
-    verify(expectedReconfigurations, MUST_BE_ERROR_FREE);
+    verify(expectedResets, MUST_BE_ERROR_FREE);
   }
 
 
-  void verify(long expectedReconfigurations, boolean errorFreeness) {
+  void verify(int expected, boolean errorFreeness) {
     StatusChecker checker = new StatusChecker(loggerContext);
     StatusPrinter.print(loggerContext);
     if (errorFreeness == MUST_BE_ERROR_FREE) {
@@ -280,23 +258,17 @@ public class ReconfigureOnChangeTest {
     } else {
       assertFalse(checker.isErrorFree(0));
     }
+
     int effectiveResets = checker
-            .matchCount("Will reset and reconfigure context");
-    // the number of effective resets must be equal or less than
-    // expectedReconfigurations
-    System.out.println("effectiveResets=" + effectiveResets);
+            .matchCount(CoreConstants.RESET_MSG_PREFIX);
 
-    System.out.println("expectedReconfigurations=" + expectedReconfigurations);
-    assertTrue(effectiveResets <= expectedReconfigurations);
-
-    // however, there should be some effective resets
     String failMsg = "effective=" + effectiveResets + ", expected="
-            + expectedReconfigurations;
-    // we can't have the test succeed under JDK 1.5, punt and require 1.6+
-    if (Env.isJDK6OrHigher()) {
-      assertTrue(failMsg,
-              (effectiveResets * 1.5) >= (expectedReconfigurations * 1.0));
-    }
+            + expected;
+
+    // there might be more effective resets than the expected amount
+    // since the harness may be sleeping while a reset occurs
+    assertTrue(failMsg, expected <= effectiveResets && (expected +2) >= effectiveResets);
+
   }
 
   ReconfigureOnChangeFilter initROCF() throws MalformedURLException {
@@ -375,14 +347,10 @@ public class ReconfigureOnChangeTest {
 
   enum UpdateType {TOUCH, MALFORMED, MALFORMED_INNER}
 
-  void writeToFile(File file, String contents) {
-    try {
-      FileWriter fw = new FileWriter(file);
-      fw.write(contents);
-      fw.close();
-    } catch (IOException e) {
-      e.printStackTrace();
-    }
+  void writeToFile(File file, String contents) throws IOException {
+    FileWriter fw = new FileWriter(file);
+    fw.write(contents);
+    fw.close();
   }
 
   class Updater extends RunnableWithCounterAndDone {
@@ -414,21 +382,31 @@ public class ReconfigureOnChangeTest {
             touchFile();
             break;
           case MALFORMED:
-            malformedUpdate(counter);
+            try {
+              malformedUpdate(counter);
+            } catch (IOException e) {
+              e.printStackTrace();
+              fail("malformedUpdate failed");
+            }
             break;
           case MALFORMED_INNER:
-            malformedInnerUpdate(counter);
+            try {
+              malformedInnerUpdate(counter);
+            } catch (IOException e) {
+              e.printStackTrace();
+              fail("malformedInnerUpdate failed");
+            }
         }
       }
     }
 
-    private void malformedUpdate(long counter) {
+    private void malformedUpdate(long counter) throws IOException {
       writeToFile(configFile, "<configuration scan=\"true\" scanPeriod=\"50 millisecond\">\n" +
               "  <root level=\"ERROR\">\n" +
               "</configuration>");
     }
 
-    private void malformedInnerUpdate(long counter) {
+    private void malformedInnerUpdate(long counter)  throws IOException {
       writeToFile(configFile, "<included>\n" +
               "  <root>\n" +
               "</included>");
