@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2009, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -14,6 +14,7 @@
 package ch.qos.logback.core;
 
 import java.util.Map;
+import java.util.concurrent.ExecutorService;
 
 import ch.qos.logback.core.spi.PropertyContainer;
 import ch.qos.logback.core.status.StatusManager;
@@ -103,4 +104,13 @@ public interface Context extends PropertyContainer {
    */
   public Object getConfigurationLock();
 
+
+  /**
+   * Every context has an ExecutorService which be invoked to execute certain
+   * tasks in a separate thread.
+   *
+   * @return the executor for this context.
+   * @since 1.0.0
+   */
+  public ExecutorService getExecutorService();
 }
