@@ -1,24 +1,25 @@
 
-document.write('<table class="footer">')
+document.write('<table class="footer" border="0">')
 
 document.write('<tr>')
 
-document.write('  <td>')
-document.write('  &nbsp;')
-//document.write('    <a href="http://validator.w3.org/check?uri=referer">')
-//document.write('      <img align="left" src="http://www.w3.org/Icons/valid-xhtml10"') 
-//document.write('           alt="Valid XHTML 1.0 Transitional" height="31" width="88" /></a>')
-document.write('   </td>')
-
 document.write('<td valign="top">Copyright &copy; 2011  <a href="http://www.qos.ch/">QOS.ch</a></td>')
+
+document.write('  <td rowspan="2">')
+document.write('    <script type="text/javascript" src="http://www.ohloh.net/p/13616/widgets/project_users.js"></script>')
+document.write('  </td>')
+
+
 document.write('</tr>')
 
 AAT = '@'
 DOOTT = '.'
 document.write('<tr>') 
-document.write('<td align="left" colspan="2">') 
+
+document.write('<td align="left" colspan="1">') 
 document.write('We are actively looking for volunteers to proofread the documentation. Please send your corrections or suggestions for improvement to "corrections' + AAT +'qos'+DOOTT+'ch". See also the <a href="http://articles.qos.ch/contributing.html">instructions for contributors</a>.');
 document.write('</td>') 
+document.write('  <td>&nbsp;</td>')
+document.write('</tr>') 
 
 document.write('</table>')
-
